==> kinfocenter-6.2.5.tar.xz: kinfocenter-6.2.5/kcms/pci/kcm_pci.json.cmake <==
{
    "Categories": "Qt;KDE;X-KDE-information;",
    "KPlugin": {
        "BugReportUrl": "https://bugs.kde.org/enter_bug.cgi?product=kinfocenter&component=general",
        "Description": "PCI information",
        "Description[ar]": "معلومات PCI",
        "Description[az]": "PCİ məlumatı",
        "Description[bg]": "Данни за PCI шина",
        "Description[ca@valencia]": "Informació de PCI",
        "Description[ca]": "Informació de PCI",
        "Description[cs]": "Informace o PCI",
        "Description[de]": "Informationen zu PCI",
        "Description[en_GB]": "PCI information",
        "Description[eo]": "Informoj pri PCI",
        "Description[es]": "Información sobre PCI",
        "Description[et]": "PCI info",
        "Description[eu]": "PCIren informazioa",
        "Description[fi]": "PCI-tiedot",
        "Description[fr]": "Informations concernant l'interface PCI",
        "Description[gl]": "Información de PCI.",
        "Description[he]": "פרטי התקני PCI",
        "Description[hu]": "PCI-információk",
        "Description[ia]": "Information de PCI",
        "Description[id]": "Informasi PCI",
        "Description[is]": "Upplýsingar um PCI-braut",
        "Description[it]": "Informazioni sul bus PCI",
        "Description[ja]": "PCI の情報",
        "Description[ka]": "PCI მოწყობილობები",
        "Description[ko]": "PCI 정보",
        "Description[lt]": "Informacija apie PCI",
        "Description[nl]": "PCI-informatie",
        "Description[nn]": "PCI-informasjon",
        "Description[pa]": "PCI ਜਾਣਕਾਰੀ",
        "Description[pl]": "Szczegóły o PCI",
        "Description[pt]": "Informação sobre o PCI",
        "Description[pt_BR]": "Informações PCI",
        "Description[ro]": "Informații despre PCI",
        "Description[ru]": "Сведения об устройствах PCI",
        "Description[sk]": "Informácie o PCI",
        "Description[sl]": "Podatki o vodilu PCI",
        "Description[sv]": "Information om PCI",
        "Description[ta]": "PCI விவரங்கள்",
        "Description[tr]": "PCI Bilgisi",
        "Description[uk]": "Інформація щодо шини PCI",
        "Description[vi]": "Thông tin về PCI",
        "Description[x-test]": "xxPCI informationxx",
        "Description[zh_CN]": "PCI 信息",
        "Description[zh_TW]": "PCI 資訊",
        "Icon": "hwinfo",
        "Name": "PCI",
        "Name[af]": "PCI",
        "Name[ar]": "PCI",
        "Name[as]": "PCI",
        "Name[ast]": "PCI",
        "Name[az]": "PCI",
        "Name[be@latin]": "PCI",
        "Name[be]": "PCI",
        "Name[bg]": "PCI",
        "Name[bn]": "পি-সি-আই",
        "Name[bn_IN]": "PCI",
        "Name[br]": "PCI",
        "Name[bs]": "PCI",
        "Name[ca@valencia]": "PCI",
        "Name[ca]": "PCI",
        "Name[cs]": "PCI sběrnice",
        "Name[csb]": "PCI",
        "Name[cy]": "PCI",
        "Name[da]": "PCI",
        "Name[de]": "PCI",
        "Name[el]": "PCI",
        "Name[en_GB]": "PCI",
        "Name[eo]": "PCI",
        "Name[es]": "PCI",
        "Name[et]": "PCI",
        "Name[eu]": "PCI",
        "Name[fi]": "PCI",
        "Name[fr]": "PCI",
        "Name[fy]": "PCI",
        "Name[ga]": "PCI",
        "Name[gl]": "PCI",
        "Name[gu]": "PCI",
        "Name[he]": "התקני PCI",
        "Name[hi]": "पीसीआई",
        "Name[hne]": "पीसीआई",
        "Name[hr]": "PCI",
        "Name[hsb]": "PCI",
        "Name[hu]": "PCI",
        "Name[ia]": "PCI",
        "Name[id]": "PCI",
        "Name[is]": "PCI-braut",
        "Name[it]": "PCI",
        "Name[ja]": "PCI",
        "Name[ka]": "PCI",
        "Name[kk]": "PCI",
        "Name[km]": "PCI",
        "Name[kn]": "ಪಿಸಿಐ",
        "Name[ko]": "PCI",
        "Name[ku]": "PCI",
        "Name[lt]": "PCI",
        "Name[lv]": "PCI",
        "Name[mai]": "पीसीआई",
        "Name[mk]": "PCI",
        "Name[ml]": "പിസിഐ",
        "Name[mr]": "PCI",
        "Name[ms]": "PCI",
        "Name[nb]": "PCI",
        "Name[nds]": "PCI",
        "Name[ne]": "पीसीआई",
        "Name[nl]": "PCI",
        "Name[nn]": "PCI",
        "Name[oc]": "PCI",
        "Name[or]": "PCI",
        "Name[pa]": "PCI",
        "Name[pl]": "PCI",
        "Name[pt]": "PCI",
        "Name[pt_BR]": "PCI",
        "Name[ro]": "PCI",
        "Name[ru]": "PCI",
        "Name[se]": "PCI",
        "Name[si]": "PCI",
        "Name[sk]": "PCI",
        "Name[sl]": "PCI",
        "Name[sr@ijekavian]": "ПЦИ",
        "Name[sr@ijekavianlatin]": "PCI",
        "Name[sr@latin]": "PCI",
        "Name[sr]": "ПЦИ",
        "Name[sv]": "PCI",
        "Name[ta]": "PCI",
        "Name[te]": "పి సి ఐ",
        "Name[tg]": "PCI",
        "Name[th]": "อุปกรณ์ PCI",
        "Name[tr]": "PCI",
        "Name[ug]": "PCI",
        "Name[uk]": "Шина PCI",
        "Name[uz@cyrillic]": "PCI",
        "Name[uz]": "PCI",
        "Name[vi]": "PCI",
        "Name[wa]": "PCI",
        "Name[x-test]": "xxPCIxx",
        "Name[xh]": "PCI",
        "Name[zh_CN]": "PCI",
        "Name[zh_TW]": "PCI"
    },
    "TryExec": "@PCI_BACKEND@",
    "X-KDE-KInfoCenter-Category": "device_information",
    "X-KDE-Keywords": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[ar]": "PCI,أجهزة PCI,PCI-Bus,معلومات النّظام",
    "X-KDE-Keywords[az]": "PCI,PCI-Devices,PCI-Bus,System Information,PCİ yolu,PCİ cihazı,sistem haqqında məlumat",
    "X-KDE-Keywords[bg]": "PCI,PCI-устройства,PCI-шина,системна информация",
    "X-KDE-Keywords[bs]": "PCI,PCI-uređaji,PCI-Bus,Sistemske informacije",
    "X-KDE-Keywords[ca@valencia]": "PCI,Dispositius PCI,Bus PCI,Informació del sistema",
    "X-KDE-Keywords[ca]": "PCI,Dispositius PCI,Bus PCI,Informació del sistema",
    "X-KDE-Keywords[cs]": "PCI,Zařízení PCI,Sběrnice PCI,Informace o systému",
    "X-KDE-Keywords[da]": "PCI,PCI-enheder,PCI-Bus,Systeminformation",
    "X-KDE-Keywords[de]": "PCI,PCI-Geräte,PCI-Bus,Systeminformationen",
    "X-KDE-Keywords[el]": "PCI,PCI-συσκευές,PCI-Bus,πληροφορίες συστήματος",
    "X-KDE-Keywords[en_GB]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[es]": "PCI,Dispositivos-PCI,Bus-PCI,Información sobre el sistema",
    "X-KDE-Keywords[et]": "PCI,PCI seadmed,PCI siin,süsteemi teave",
    "X-KDE-Keywords[eu]": "PCI,PCI gailuak,PCI busa,sistema-informazioa",
    "X-KDE-Keywords[fi]": "PCI,PCI-laitteet,PCI-väylä,järjestelmätiedot",
    "X-KDE-Keywords[fr]": "PCI, Périphériques PCI, Bus PCI, Informations Système",
    "X-KDE-Keywords[ga]": "PCI,Gléasanna PCI,Bun PCI,Eolas faoin Chóras",
    "X-KDE-Keywords[gl]": "PCI,dispositivos PCI,bus PCI,Información do sistema",
    "X-KDE-Keywords[he]": "Interrupts,IRQ,System Information,פסיקות,מידע,פרטי מערכת",
    "X-KDE-Keywords[hu]": "PCI,PCI eszközök,PCI busz,Rendszerinformáció",
    "X-KDE-Keywords[ia]": "PCI,Dispositivos PCI,Bus PCI,Information de systema",
    "X-KDE-Keywords[it]": "PCI,dispositivi PCI,bus PCI,Informazioni di sistema",
    "X-KDE-Keywords[ka]": "PCI,PCI-Devices,PCI-Bus,System Information,სისტემის ინფორმაცია",
    "X-KDE-Keywords[kk]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[km]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[ko]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI 장치,PCI 버스,시스템 정보",
    "X-KDE-Keywords[lt]": "PCI,PCI įrenginiai,PCI irenginiai,PCI magistralės,PCI magistrales,sistemos informacija,informacija apie sistemą,informacija apie sistema",
    "X-KDE-Keywords[mr]": "PCI,PCI-साधन,PCI-Bus प्रणाली माहीती",
    "X-KDE-Keywords[nb]": "PCI,PCI-enheter,PCI-buss,Systeminformasjon",
    "X-KDE-Keywords[nds]": "PCI,PCI-Reedschappen,PCI-Bus,Systeem-Informatschonen",
    "X-KDE-Keywords[nl]": "PCI,PCI-apparaten,PCI-Bus,systeeminformatie",
    "X-KDE-Keywords[nn]": "PCI,PCI-einingar,PCI-buss,systeminformasjon",
    "X-KDE-Keywords[pa]": "PCI,PCI-ਡਿਵਾਈਸ,PCI-ਜੰਤਰ,PCI-ਬੱਸ,ਸਿਸਟਮ ਜਾਣਕਾਰੀ",
    "X-KDE-Keywords[pl]": "PCI,Urządzenia-PCI,Szyna-PCI,Dane o systemie",
    "X-KDE-Keywords[pt_BR]": "PCI,Dispositivos PCI,Barramento PCI,Informação do sistema",
    "X-KDE-Keywords[ro]": "PCI,dispozitive PCI,PCI-Bus,informații sistem",
    "X-KDE-Keywords[ru]": "PCI,PCI-Devices,PCI-Bus,System Information,шина PCI, PCI устройства,сведения о системе",
    "X-KDE-Keywords[sk]": "PCI,PCI zariadenia,PCI zbernice,Systémové informácie",
    "X-KDE-Keywords[sl]": "PCI,naprave PCI,vodilo PCI,sistemski podatki,podatki o sistemu",
    "X-KDE-Keywords[sr@ijekavian]": "PCI,PCI-Devices,PCI-Bus,System Information,ПЦИ,ПЦИ уређаји,ПЦИ магистрала,системске информације",
    "X-KDE-Keywords[sr@ijekavianlatin]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI,PCI uređaji,PCI magistrala,sistemske informacije",
    "X-KDE-Keywords[sr@latin]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI,PCI uređaji,PCI magistrala,sistemske informacije",
    "X-KDE-Keywords[sr]": "PCI,PCI-Devices,PCI-Bus,System Information,ПЦИ,ПЦИ уређаји,ПЦИ магистрала,системске информације",
    "X-KDE-Keywords[sv]": "PCI,PCI-Enheter,PCI-Buss,Systeminformation",
    "X-KDE-Keywords[tr]": "pci,pci aygıtları,pci cihazları,pci veri yolu,sistem bilgisi",
    "X-KDE-Keywords[uk]": "PCI,PCI-Devices,PCI-Bus,System Information,пристрій,пристрої,канал,шина,система,інформація,відомості",
    "X-KDE-Keywords[vi]": "PCI,PCI-Devices,PCI-Bus,System Information,Thiết bị PCI,Buýt PCI,Thông tin hệ thống",
    "X-KDE-Keywords[zh_CN]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI shebei,PCI zongxian,xitongxinxi,PCI 设备,PCI 总线,系统信息",
    "X-KDE-Keywords[zh_TW]": "PCI,PCI-Devices,PCI-Bus,System Information"
}

==> kinfocenter-6.2.90.tar.xz: kinfocenter-6.2.90/kcms/pci/kcm_pci.json.cmake <==
{
    "Categories": "Qt;KDE;X-KDE-information;",
    "KPlugin": {
        "BugReportUrl": "https://bugs.kde.org/enter_bug.cgi?product=kinfocenter&component=general",
        "Description": "PCI information",
        "Description[ar]": "معلومات PCI",
        "Description[az]": "PCİ məlumatı",
        "Description[bg]": "Данни за PCI шина",
        "Description[ca@valencia]": "Informació de PCI",
        "Description[ca]": "Informació de PCI",
        "Description[cs]": "Informace o PCI",
        "Description[da]": "PCI-information",
        "Description[de]": "Informationen zu PCI",
        "Description[el]": "Πληροφορίες PCI",
        "Description[en_GB]": "PCI information",
        "Description[eo]": "Informoj pri PCI",
        "Description[es]": "Información sobre PCI",
        "Description[et]": "PCI info",
        "Description[eu]": "PCIren informazioa",
        "Description[fi]": "PCI-tiedot",
        "Description[fr]": "Informations concernant l'interface PCI",
        "Description[gl]": "Información de PCI.",
        "Description[he]": "פרטי התקני PCI",
        "Description[hu]": "PCI-információk",
        "Description[ia]": "Information de PCI",
        "Description[id]": "Informasi PCI",
        "Description[is]": "Upplýsingar um PCI-braut",
        "Description[it]": "Informazioni sul bus PCI",
        "Description[ja]": "PCI の情報",
        "Description[ka]": "PCI მოწყობილობები",
        "Description[ko]": "PCI 정보",
        "Description[lt]": "Informacija apie PCI",
        "Description[lv]": "PCI informācija",
        "Description[nl]": "PCI-informatie",
        "Description[nn]": "PCI-informasjon",
        "Description[pa]": "PCI ਜਾਣਕਾਰੀ",
        "Description[pl]": "Szczegóły o PCI",
        "Description[pt]": "Informação sobre o PCI",
        "Description[pt_BR]": "Informações PCI",
        "Description[ro]": "Informații despre PCI",
        "Description[ru]": "Сведения об устройствах PCI",
        "Description[sa]": "PCI सूचना",
        "Description[sk]": "Informácie o PCI",
        "Description[sl]": "Podatki o vodilu PCI",
        "Description[sv]": "Information om PCI",
        "Description[ta]": "PCI விவரங்கள்",
        "Description[tr]": "PCI Bilgisi",
        "Description[uk]": "Інформація щодо шини PCI",
        "Description[vi]": "Thông tin về PCI",
        "Description[x-test]": "xxPCI informationxx",
        "Description[zh_CN]": "PCI 信息",
        "Description[zh_TW]": "PCI 資訊",
        "Icon": "hwinfo",
        "Name": "PCI",
        "Name[af]": "PCI",
        "Name[ar]": "PCI",
        "Name[as]": "PCI",
        "Name[ast]": "PCI",
        "Name[az]": "PCI",
        "Name[be@latin]": "PCI",
        "Name[be]": "PCI",
        "Name[bg]": "PCI",
        "Name[bn]": "পি-সি-আই",
        "Name[bn_IN]": "PCI",
        "Name[br]": "PCI",
        "Name[bs]": "PCI",
        "Name[ca@valencia]": "PCI",
        "Name[ca]": "PCI",
        "Name[cs]": "PCI sběrnice",
        "Name[csb]": "PCI",
        "Name[cy]": "PCI",
        "Name[da]": "PCI",
        "Name[de]": "PCI",
        "Name[el]": "PCI",
        "Name[en_GB]": "PCI",
        "Name[eo]": "PCI",
        "Name[es]": "PCI",
        "Name[et]": "PCI",
        "Name[eu]": "PCI",
        "Name[fi]": "PCI",
        "Name[fr]": "PCI",
        "Name[fy]": "PCI",
        "Name[ga]": "PCI",
        "Name[gl]": "PCI",
        "Name[gu]": "PCI",
        "Name[he]": "התקני PCI",
        "Name[hi]": "पीसीआई",
        "Name[hne]": "पीसीआई",
        "Name[hr]": "PCI",
        "Name[hsb]": "PCI",
        "Name[hu]": "PCI",
        "Name[ia]": "PCI",
        "Name[id]": "PCI",
        "Name[is]": "PCI-braut",
        "Name[it]": "PCI",
        "Name[ja]": "PCI",
        "Name[ka]": "PCI",
        "Name[kk]": "PCI",
        "Name[km]": "PCI",
        "Name[kn]": "ಪಿಸಿಐ",
        "Name[ko]": "PCI",
        "Name[ku]": "PCI",
        "Name[lt]": "PCI",
        "Name[lv]": "PCI",
        "Name[mai]": "पीसीआई",
        "Name[mk]": "PCI",
        "Name[ml]": "പിസിഐ",
        "Name[mr]": "PCI",
        "Name[ms]": "PCI",
        "Name[nb]": "PCI",
        "Name[nds]": "PCI",
        "Name[ne]": "पीसीआई",
        "Name[nl]": "PCI",
        "Name[nn]": "PCI",
        "Name[oc]": "PCI",
        "Name[or]": "PCI",
        "Name[pa]": "PCI",
        "Name[pl]": "PCI",
        "Name[pt]": "PCI",
        "Name[pt_BR]": "PCI",
        "Name[ro]": "PCI",
        "Name[ru]": "PCI",
        "Name[sa]": "पीसीआई",
        "Name[se]": "PCI",
        "Name[si]": "PCI",
        "Name[sk]": "PCI",
        "Name[sl]": "PCI",
        "Name[sr@ijekavian]": "ПЦИ",
        "Name[sr@ijekavianlatin]": "PCI",
        "Name[sr@latin]": "PCI",
        "Name[sr]": "ПЦИ",
        "Name[sv]": "PCI",
        "Name[ta]": "PCI",
        "Name[te]": "పి సి ఐ",
        "Name[tg]": "PCI",
        "Name[th]": "อุปกรณ์ PCI",
        "Name[tr]": "PCI",
        "Name[ug]": "PCI",
        "Name[uk]": "Шина PCI",
        "Name[uz@cyrillic]": "PCI",
        "Name[uz]": "PCI",
        "Name[vi]": "PCI",
        "Name[wa]": "PCI",
        "Name[x-test]": "xxPCIxx",
        "Name[xh]": "PCI",
        "Name[zh_CN]": "PCI",
        "Name[zh_TW]": "PCI"
    },
    "TryExec": "@PCI_BACKEND@",
    "X-KDE-KInfoCenter-Category": "device_information",
    "X-KDE-Keywords": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[ar]": "PCI,أجهزة PCI,PCI-Bus,معلومات النّظام",
    "X-KDE-Keywords[az]": "PCI,PCI-Devices,PCI-Bus,System Information,PCİ yolu,PCİ cihazı,sistem haqqında məlumat",
    "X-KDE-Keywords[bg]": "PCI,PCI-устройства,PCI-шина,системна информация",
    "X-KDE-Keywords[bs]": "PCI,PCI-uređaji,PCI-Bus,Sistemske informacije",
    "X-KDE-Keywords[ca@valencia]": "PCI,Dispositius PCI,Bus PCI,Informació del sistema",
    "X-KDE-Keywords[ca]": "PCI,Dispositius PCI,Bus PCI,Informació del sistema",
    "X-KDE-Keywords[cs]": "PCI,Zařízení PCI,Sběrnice PCI,Informace o systému",
    "X-KDE-Keywords[da]": "PCI,PCI-enheder,PCI-Bus,Systeminformation",
    "X-KDE-Keywords[de]": "PCI,PCI-Geräte,PCI-Bus,Systeminformationen",
    "X-KDE-Keywords[el]": "PCI,PCI-συσκευές,PCI-Bus,πληροφορίες συστήματος",
    "X-KDE-Keywords[en_GB]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[es]": "PCI,Dispositivos-PCI,Bus-PCI,Información sobre el sistema",
    "X-KDE-Keywords[et]": "PCI,PCI seadmed,PCI siin,süsteemi teave",
    "X-KDE-Keywords[eu]": "PCI,PCI gailuak,PCI busa,sistema-informazioa",
    "X-KDE-Keywords[fi]": "PCI,PCI-laitteet,PCI-väylä,järjestelmätiedot",
    "X-KDE-Keywords[fr]": "PCI, Périphériques PCI, Bus PCI, Informations Système",
    "X-KDE-Keywords[ga]": "PCI,Gléasanna PCI,Bun PCI,Eolas faoin Chóras",
    "X-KDE-Keywords[gl]": "PCI,dispositivos PCI,bus PCI,Información do sistema",
    "X-KDE-Keywords[he]": "Interrupts,IRQ,System Information,פסיקות,מידע,פרטי מערכת",
    "X-KDE-Keywords[hu]": "PCI,PCI eszközök,PCI busz,Rendszerinformáció",
    "X-KDE-Keywords[ia]": "PCI,Dispositivos PCI,Bus PCI,Information de systema",
    "X-KDE-Keywords[it]": "PCI,dispositivi PCI,bus PCI,Informazioni di sistema",
    "X-KDE-Keywords[ka]": "PCI,PCI-Devices,PCI-Bus,System Information,სისტემის ინფორმაცია",
    "X-KDE-Keywords[kk]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[km]": "PCI,PCI-Devices,PCI-Bus,System Information",
    "X-KDE-Keywords[ko]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI 장치,PCI 버스,시스템 정보",
    "X-KDE-Keywords[lt]": "PCI,PCI įrenginiai,PCI irenginiai,PCI magistralės,PCI magistrales,sistemos informacija,informacija apie sistemą,informacija apie sistema",
    "X-KDE-Keywords[lv]": "PCI,PCI-ierīces,PCI kopne,sistēmas informācija",
    "X-KDE-Keywords[mr]": "PCI,PCI-साधन,PCI-Bus प्रणाली माहीती",
    "X-KDE-Keywords[nb]": "PCI,PCI-enheter,PCI-buss,Systeminformasjon",
    "X-KDE-Keywords[nds]": "PCI,PCI-Reedschappen,PCI-Bus,Systeem-Informatschonen",
    "X-KDE-Keywords[nl]": "PCI,PCI-apparaten,PCI-Bus,systeeminformatie",
    "X-KDE-Keywords[nn]": "PCI,PCI-einingar,PCI-buss,systeminformasjon",
    "X-KDE-Keywords[pa]": "PCI,PCI-ਡਿਵਾਈਸ,PCI-ਜੰਤਰ,PCI-ਬੱਸ,ਸਿਸਟਮ ਜਾਣਕਾਰੀ",
    "X-KDE-Keywords[pl]": "PCI,Urządzenia-PCI,Szyna-PCI,Dane o systemie",
    "X-KDE-Keywords[pt_BR]": "PCI,Dispositivos PCI,Barramento PCI,Informação do sistema",
    "X-KDE-Keywords[ro]": "PCI,dispozitive PCI,PCI-Bus,informații sistem",
    "X-KDE-Keywords[ru]": "PCI,PCI-Devices,PCI-Bus,System Information,шина PCI, PCI устройства,сведения о системе",
    "X-KDE-Keywords[sa]": "PCI,PCI-Devices,PCI-Bus,प्रणाली सूचना",
    "X-KDE-Keywords[sk]": "PCI,PCI zariadenia,PCI zbernice,Systémové informácie",
    "X-KDE-Keywords[sl]": "PCI,naprave PCI,vodilo PCI,sistemski podatki,podatki o sistemu",
    "X-KDE-Keywords[sr@ijekavian]": "PCI,PCI-Devices,PCI-Bus,System Information,ПЦИ,ПЦИ уређаји,ПЦИ магистрала,системске информације",
    "X-KDE-Keywords[sr@ijekavianlatin]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI,PCI uređaji,PCI magistrala,sistemske informacije",
    "X-KDE-Keywords[sr@latin]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI,PCI uređaji,PCI magistrala,sistemske informacije",
    "X-KDE-Keywords[sr]": "PCI,PCI-Devices,PCI-Bus,System Information,ПЦИ,ПЦИ уређаји,ПЦИ магистрала,системске информације",
    "X-KDE-Keywords[sv]": "PCI,PCI-Enheter,PCI-Buss,Systeminformation",
    "X-KDE-Keywords[tr]": "pci,pci aygıtları,pci cihazları,pci veri yolu,sistem bilgisi",
    "X-KDE-Keywords[uk]": "PCI,PCI-Devices,PCI-Bus,System Information,пристрій,пристрої,канал,шина,система,інформація,відомості",
    "X-KDE-Keywords[vi]": "PCI,PCI-Devices,PCI-Bus,System Information,Thiết bị PCI,Buýt PCI,Thông tin hệ thống",
    "X-KDE-Keywords[x-test]": "xxPCIxx,xxPCI-Devicesxx,xxPCI-Busxx,xxSystem Informationxx",
    "X-KDE-Keywords[zh_CN]": "PCI,PCI-Devices,PCI-Bus,System Information,PCI shebei,PCI zongxian,xitongxinxi,PCI 设备,PCI 总线,系统信息",
    "X-KDE-Keywords[zh_TW]": "PCI,PCI-Devices,PCI-Bus,System Information"
}
